
rule gff2bed:
	input:
		gff=config['annotation']

	output:
		"0.gmap/annotation.bed"
	message: " Conversion de l'annotation GFF au format BED: gff2bed"
	threads: 1
	log: "0.gmap/gff2bed.log"
	params:
		featuretype=config['featuretype']

	shell:
		"./bin/gff2bed.sh {input.gff} {params.featuretype} > {output}"

rule bed2fasta:
	input:
		fastain=config['genome'],
		bed="0.gmap/annotation.bed"

	output:
		"0.gmap/annotation.fasta"
	message: "Extraction des features au format fasta: bedtools getfasta"
	threads: 1
	log: "0.gmap/bedtools_getfasta.log"
	shell:
		"bedtools getfasta -fi {input.fastain} -fo {output} -bed {input.bed} -name+"

rule fastacompo:
	input:
		"0.gmap/annotation.fasta"

	output:
		"0.gmap/annotation.nuclComposition.csv"

	message: "Recuperation de la composition nucleotidique des séquences: seqtk comp"
	log: "0.gmap/seqtk.log"
	threads: 1
	shell:
		"seqtk comp {input} > {output}"

rule gmapl:
	input:
		query="0.gmap/annotation.fasta",
		dbpath=config['gmapdbpath']

	output:
		"0.gmap/gmap.psl"

	message: "Mapping des séquences sur le génome de référence: gmapl"
	threads: 6
	log: "0.gmap/gmapl.log"
	params:
		threads=6,
		format=1,
		db=config['gmapdb']

	shell:
		"gmapl --nosplicing -D {input.dbpath} -d {params.db} -f {params.format} -t {params.threads} --cross-species {input.query} > {output}"

rule check_mapped_features:
	input:
		gmap="0.gmap/gmap.psl",
		annot="0.gmap/annotation.bed"
	output:
		mapped="0.gmap/mapped.ids",
		unmapped="0.gmap/unmapped.ids"
	message: "verification des séquences mappées/unmapped"
	log: "0.gmap/check_mapped_features.log"
	threads: 1
	shell:
		"""
		cut -f 10 {input.gmap} |cut -f 1 -d ':'|sort -u > {output.mapped}
		fgrep -wvf {output.mapped} {input.annot} |cut -f 4|sort -u > {output.unmapped} 
		"""

rule gmapstats:
	input:
		"0.gmap/gmap.psl"
	output:
		directory("1.gmap-parsed")
	message: "Parsing of GMAP results."
	log: "1.gmap-parsed/gmapstats.log"
	threads: 1
	shell:
		"bin/gmapstats.py -i {input} -o {output}"